Module value

Module value 

Trait and impls for values writable through a JsonBackend.

Structs

Null
Marker type representing a JSON null value.

Traits

WriteVal
A value that can be written through a JsonBackend.